/*
 *  This file is part of the nuvtools package
 *  Copyright (C) 2004 Gavin Hurlbut
 *
 *  nuvtools is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*HEADER---------------------------------------------------
* $Id: queue.h 41 2004-12-12 01:15:22Z gjhurlbu $
*
* Copyright 2004 Gavin Hurlbut
* All rights reserved
*
* Comments :
*
* Revision History:
* $Log: queue.h,v $
* Revision 1.1  2004/12/12 01:15:21  gjhurlbu
* - moved queue, linked_list and logging to libnuvtools
*
* Revision 1.2  2004/11/06 15:19:57  gjhurlbu
* - Added GPL Copyright notices
*
* Revision 1.1  2004/09/13 05:29:19  gjhurlbu
* - converted to threaded
*
*
*
*--------------------------------------------------------*/
#ifndef queue_h_
#define queue_h_

#include "environment.h"
#include <pthread.h>

/* CVS generated ID string (optional for h files) */
static char queue_h_ident[] _UNUSED_ = 
    "$Id: queue.h 41 2004-12-12 01:15:22Z gjhurlbu $";


typedef void * QueueItem_t;
typedef struct 
{ 
    uint32 numElements;
    uint32 numMask;
    uint32 head;
    uint32 tail;
    QueueItem_t *itemTable;
    pthread_mutex_t *mutex;
    bool full;
    pthread_cond_t *cNotFull;
    bool empty;
    pthread_cond_t *cNotEmpty;
} QueueObject_t;


#ifdef __cplusplus
extern "C" {
#endif

/* Function Prototypes */
QueueObject_t * QueueCreate( uint32 numElements );
bool QueueEnqueueItem( QueueObject_t *queue, QueueItem_t item ); 
QueueItem_t QueueDequeueItem( QueueObject_t *queue, int32 ms_timeout );
void QueueClear( QueueObject_t *queue, bool freeItems );
uint32 QueueUsed( QueueObject_t *queue );

#ifdef __cplusplus
}
#endif

#endif
