/*
 *  This file is part of the nuvtools package
 *  Copyright (C) 2004, 2005 Gavin Hurlbut
 *
 *  nuvtools is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*HEADER---------------------------------------------------
* $Id: reader.c 105 2005-04-24 03:10:16Z gjhurlbu $
*
* Copyright 2004, 2005 Gavin Hurlbut
* All rights reserved
*
*/

#include "environment.h"
#include <stdlib.h>
#include <stdio.h>
#include "format.h"
#include "nuvread.h"
#include "queue.h"
#include "types.h"
#include "logging.h"


/* CVS generated ID string */
static char ident[] _UNUSED_ = 
    "$Id: reader.c 105 2005-04-24 03:10:16Z gjhurlbu $";


extern QueueObject_t *ResyncQueue;
extern bool GlobalAbort;

void *ReaderThread( void *arg )
{
    char           *filename;
    nuvFile        *nv;
    nuvFrame       *frame;
    char           *outCodec = "XVID";

    filename = (char *)arg;

    nv = nuv_init( filename, 0 );
    if( !nv ) {
        fprintf( stderr, "Unable to open file" );
        return( NULL );
    }
    
    memcpy( &nv->out_video_4cc, outCodec, 4 ); 

    frame = nuv_new_frame();
    if( !frame ) {
        fprintf( stderr, "Can't pass config to the reencode thread" );
        return( NULL );
    }

    frame->header.frametype = 'I';
    frame->length = sizeof( nuvFile );
    frame->data = (char *)malloc(sizeof(nuvFile));
    memcpy( frame->data, nv, sizeof(nuvFile) );
    QueueEnqueueItem( ResyncQueue, (QueueItem_t)frame );

    while( (frame = nuv_read_frame( nv, "AVS" )) ) {
        if( GlobalAbort ) {
            return( NULL );
        }
        QueueEnqueueItem( ResyncQueue, (QueueItem_t)frame );
    }

#if 0
    printf( "\nTotal NUV Frame Count Read: %lld\n\n", nv->frameCount );
#endif

    nuv_free_file(nv);

    frame = nuv_new_frame();
    if( !frame ) {
        fprintf( stderr, "Can't pass end frame to the reencode thread" );
        return( NULL );
    }

    frame->header.frametype = 'E';
    frame->length = 0;
    frame->data = NULL;
    QueueEnqueueItem( ResyncQueue, (QueueItem_t)frame );

    return( NULL );
}


/*
 * vim:ts=4:sw=4:ai:et:si:sts=4
 */
