/*
 *  This file is part of the nuvtools package
 *  Copyright (C) 2004 Gavin Hurlbut
 *
 *  nuvtools is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/* Force Large-File Support */
#undef _FILE_OFFSET_BITS
#define _FILE_OFFSET_BITS 64

#define _LARGEFILE_SOURCE

#define O_LARGEFILE 0

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <ctype.h>

#include "format.h"
#include "nuvread.h"
#include "release.h"


#ifndef TRUE
#define TRUE 1
#endif

#ifndef FALSE
#define FALSE 0
#endif

#define BYTE(val,num) ((char)(((val) >> (8 * (num))) & 0xFF))

int nuvScan( char *filename );

int nuvScan( char *filename )
{
    nuvFile        *nv;
    nuvFrame       *frame;

    printf( "nuvscan  (c) 2004 Gavin Hurlbut\n" );
    printf( "%s\n", svn_version() );

    nv = nuv_init( filename, TRUE );
    if( !nv ) {
        fprintf( stderr, "Unable to open file" );
        return( 1 );
    }

    while( (frame = nuv_read_frame(nv, "AVSTRDXQK")) ) {
        nuv_dump_frame(nv, frame);
        nuv_free_frame(frame);
    }

    printf( "\nTotal NUV Frame Count: %lld\n\n", nv->frameCount );

    nuv_free_file(nv);

    return( 0 );
}

int main( int argc, char **argv )
{
    int     i;
    int     ret;

    if( argc == 1 ) {
        return( -1 );
    }

    for( i = 1; i < argc; i++ ) {
        ret = nuvScan( argv[i] );
        if( ret ) {
            return( ret );
        }
    }

    return( 0 );
}


/*
 * vim:ts=4:sw=4:ai:et:si:sts=4
 */
